<?php

namespace App\Delivery\Dhl\StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for LandedCostType StructType
 * @subpackage Structs
 */
class LandedCostType extends AbstractStructBase
{
    /**
     * The GetItemCostBreakdown
     * Meta information extracted from the WSDL
     * - documentation: If the value is "Y", the item cost breakdown will be returned.
     * @var string
     */
    public $GetItemCostBreakdown;
    /**
     * The ShipmentCurrencyCode
     * Meta information extracted from the WSDL
     * - documentation: This will be used for other amount section if the specific currency code is not provided.
     * - base: xsd:token
     * - maxLength: 3
     * - minLength: 3
     * - whiteSpace: collapse
     * @var string
     */
    public $ShipmentCurrencyCode;
    /**
     * The ShipmentPurpose
     * Meta information extracted from the WSDL
     * - documentation: Possible values: "COMMERCIAL" "PERSONAL"
     * - minOccurs: 0
     * @var string
     */
    public $ShipmentPurpose;
    /**
     * The ShipmentTransportationMode
     * Meta information extracted from the WSDL
     * - documentation: Possible value: "AIR" "OCEAN" "GROUND"
     * - minOccurs: 0
     * @var string
     */
    public $ShipmentTransportationMode;
    /**
     * The MerchantSelectedCarrierName
     * Meta information extracted from the WSDL
     * - documentation: Carrier Name from Merchant Example: DHL, UPS, FEDEX
     * - minOccurs: 0
     * @var string
     */
    public $MerchantSelectedCarrierName;
    /**
     * The Items
     * @var \App\Delivery\Dhl\StructType\ItemsType
     */
    public $Items;
    /**
     * The ShipmentMonetaryAmount
     * Meta information extracted from the WSDL
     * - minOccurs: 0
     * @var \App\Delivery\Dhl\StructType\ShipmentMonetaryAmountType
     */
    public $ShipmentMonetaryAmount;
    /**
     * The GetTariffFormula
     * Meta information extracted from the WSDL
     * - documentation: when set to “Y”, the service returns the Tariff Rate Formula for the duty/tax/fee calculation on Shipment or/and Line Item Level
     * - default: N
     * - minOccurs: 0
     * @var string
     */
    public $GetTariffFormula;
    /**
     * The GetQuotationID
     * Meta information extracted from the WSDL
     * - documentation: when set to “Y”, the service returns the unique quotation id for successful landed cost estimation which may be used internally to correlate the estimated landed cost and actual cost charged
     * - default: N
     * - minOccurs: 0
     * @var string
     */
    public $GetQuotationID;
    /**
     * The GetDetailedLineItemLevelStatus
     * Meta information extracted from the WSDL
     * - documentation: when set to “Y”, the service returns line item level number error
     * - default: N
     * - minOccurs: 0
     * @var string
     */
    public $GetDetailedLineItemLevelStatus;
    /**
     * Constructor method for LandedCostType
     * @uses LandedCostType::setGetItemCostBreakdown()
     * @uses LandedCostType::setShipmentCurrencyCode()
     * @uses LandedCostType::setShipmentPurpose()
     * @uses LandedCostType::setShipmentTransportationMode()
     * @uses LandedCostType::setMerchantSelectedCarrierName()
     * @uses LandedCostType::setItems()
     * @uses LandedCostType::setShipmentMonetaryAmount()
     * @uses LandedCostType::setGetTariffFormula()
     * @uses LandedCostType::setGetQuotationID()
     * @uses LandedCostType::setGetDetailedLineItemLevelStatus()
     * @param string $getItemCostBreakdown
     * @param string $shipmentCurrencyCode
     * @param string $shipmentPurpose
     * @param string $shipmentTransportationMode
     * @param string $merchantSelectedCarrierName
     * @param \App\Delivery\Dhl\StructType\ItemsType $items
     * @param \App\Delivery\Dhl\StructType\ShipmentMonetaryAmountType $shipmentMonetaryAmount
     * @param string $getTariffFormula
     * @param string $getQuotationID
     * @param string $getDetailedLineItemLevelStatus
     */
    public function __construct($getItemCostBreakdown = null, $shipmentCurrencyCode = null, $shipmentPurpose = null, $shipmentTransportationMode = null, $merchantSelectedCarrierName = null, \App\Delivery\Dhl\StructType\ItemsType $items = null, \App\Delivery\Dhl\StructType\ShipmentMonetaryAmountType $shipmentMonetaryAmount = null, $getTariffFormula = 'N', $getQuotationID = 'N', $getDetailedLineItemLevelStatus = 'N')
    {
        $this
            ->setGetItemCostBreakdown($getItemCostBreakdown)
            ->setShipmentCurrencyCode($shipmentCurrencyCode)
            ->setShipmentPurpose($shipmentPurpose)
            ->setShipmentTransportationMode($shipmentTransportationMode)
            ->setMerchantSelectedCarrierName($merchantSelectedCarrierName)
            ->setItems($items)
            ->setShipmentMonetaryAmount($shipmentMonetaryAmount)
            ->setGetTariffFormula($getTariffFormula)
            ->setGetQuotationID($getQuotationID)
            ->setGetDetailedLineItemLevelStatus($getDetailedLineItemLevelStatus);
    }
    /**
     * Get GetItemCostBreakdown value
     * @return string|null
     */
    public function getGetItemCostBreakdown()
    {
        return $this->GetItemCostBreakdown;
    }
    /**
     * Set GetItemCostBreakdown value
     * @uses \App\Delivery\Dhl\EnumType\GetItemCostBreakdown2::valueIsValid()
     * @uses \App\Delivery\Dhl\EnumType\GetItemCostBreakdown2::getValidValues()
     * @throws \InvalidArgumentException
     * @param string $getItemCostBreakdown
     * @return \App\Delivery\Dhl\StructType\LandedCostType
     */
    public function setGetItemCostBreakdown($getItemCostBreakdown = null)
    {
        // validation for constraint: enumeration
        if (!\App\Delivery\Dhl\EnumType\GetItemCostBreakdown2::valueIsValid($getItemCostBreakdown)) {
            throw new \InvalidArgumentException(sprintf('Invalid value(s) %s, please use one of: %s from enumeration class \App\Delivery\Dhl\EnumType\GetItemCostBreakdown2', is_array($getItemCostBreakdown) ? implode(', ', $getItemCostBreakdown) : var_export($getItemCostBreakdown, true), implode(', ', \App\Delivery\Dhl\EnumType\GetItemCostBreakdown2::getValidValues())), __LINE__);
        }
        $this->GetItemCostBreakdown = $getItemCostBreakdown;
        return $this;
    }
    /**
     * Get ShipmentCurrencyCode value
     * @return string|null
     */
    public function getShipmentCurrencyCode()
    {
        return $this->ShipmentCurrencyCode;
    }
    /**
     * Set ShipmentCurrencyCode value
     * @param string $shipmentCurrencyCode
     * @return \App\Delivery\Dhl\StructType\LandedCostType
     */
    public function setShipmentCurrencyCode($shipmentCurrencyCode = null)
    {
        // validation for constraint: string
        if (!is_null($shipmentCurrencyCode) && !is_string($shipmentCurrencyCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($shipmentCurrencyCode, true), gettype($shipmentCurrencyCode)), __LINE__);
        }
        // validation for constraint: maxLength(3)
        if (!is_null($shipmentCurrencyCode) && mb_strlen($shipmentCurrencyCode) > 3) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 3', mb_strlen($shipmentCurrencyCode)), __LINE__);
        }
        // validation for constraint: minLength(3)
        if (!is_null($shipmentCurrencyCode) && mb_strlen($shipmentCurrencyCode) < 3) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 3', mb_strlen($shipmentCurrencyCode)), __LINE__);
        }
        $this->ShipmentCurrencyCode = $shipmentCurrencyCode;
        return $this;
    }
    /**
     * Get ShipmentPurpose value
     * @return string|null
     */
    public function getShipmentPurpose()
    {
        return $this->ShipmentPurpose;
    }
    /**
     * Set ShipmentPurpose value
     * @uses \App\Delivery\Dhl\EnumType\ShipmentPurpose2::valueIsValid()
     * @uses \App\Delivery\Dhl\EnumType\ShipmentPurpose2::getValidValues()
     * @throws \InvalidArgumentException
     * @param string $shipmentPurpose
     * @return \App\Delivery\Dhl\StructType\LandedCostType
     */
    public function setShipmentPurpose($shipmentPurpose = null)
    {
        // validation for constraint: enumeration
        if (!\App\Delivery\Dhl\EnumType\ShipmentPurpose2::valueIsValid($shipmentPurpose)) {
            throw new \InvalidArgumentException(sprintf('Invalid value(s) %s, please use one of: %s from enumeration class \App\Delivery\Dhl\EnumType\ShipmentPurpose2', is_array($shipmentPurpose) ? implode(', ', $shipmentPurpose) : var_export($shipmentPurpose, true), implode(', ', \App\Delivery\Dhl\EnumType\ShipmentPurpose2::getValidValues())), __LINE__);
        }
        $this->ShipmentPurpose = $shipmentPurpose;
        return $this;
    }
    /**
     * Get ShipmentTransportationMode value
     * @return string|null
     */
    public function getShipmentTransportationMode()
    {
        return $this->ShipmentTransportationMode;
    }
    /**
     * Set ShipmentTransportationMode value
     * @uses \App\Delivery\Dhl\EnumType\ShipmentTransportationMode2::valueIsValid()
     * @uses \App\Delivery\Dhl\EnumType\ShipmentTransportationMode2::getValidValues()
     * @throws \InvalidArgumentException
     * @param string $shipmentTransportationMode
     * @return \App\Delivery\Dhl\StructType\LandedCostType
     */
    public function setShipmentTransportationMode($shipmentTransportationMode = null)
    {
        // validation for constraint: enumeration
        if (!\App\Delivery\Dhl\EnumType\ShipmentTransportationMode2::valueIsValid($shipmentTransportationMode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value(s) %s, please use one of: %s from enumeration class \App\Delivery\Dhl\EnumType\ShipmentTransportationMode2', is_array($shipmentTransportationMode) ? implode(', ', $shipmentTransportationMode) : var_export($shipmentTransportationMode, true), implode(', ', \App\Delivery\Dhl\EnumType\ShipmentTransportationMode2::getValidValues())), __LINE__);
        }
        $this->ShipmentTransportationMode = $shipmentTransportationMode;
        return $this;
    }
    /**
     * Get MerchantSelectedCarrierName value
     * @return string|null
     */
    public function getMerchantSelectedCarrierName()
    {
        return $this->MerchantSelectedCarrierName;
    }
    /**
     * Set MerchantSelectedCarrierName value
     * @uses \App\Delivery\Dhl\EnumType\MerchantSelectedCarrierName2::valueIsValid()
     * @uses \App\Delivery\Dhl\EnumType\MerchantSelectedCarrierName2::getValidValues()
     * @throws \InvalidArgumentException
     * @param string $merchantSelectedCarrierName
     * @return \App\Delivery\Dhl\StructType\LandedCostType
     */
    public function setMerchantSelectedCarrierName($merchantSelectedCarrierName = null)
    {
        // validation for constraint: enumeration
        if (!\App\Delivery\Dhl\EnumType\MerchantSelectedCarrierName2::valueIsValid($merchantSelectedCarrierName)) {
            throw new \InvalidArgumentException(sprintf('Invalid value(s) %s, please use one of: %s from enumeration class \App\Delivery\Dhl\EnumType\MerchantSelectedCarrierName2', is_array($merchantSelectedCarrierName) ? implode(', ', $merchantSelectedCarrierName) : var_export($merchantSelectedCarrierName, true), implode(', ', \App\Delivery\Dhl\EnumType\MerchantSelectedCarrierName2::getValidValues())), __LINE__);
        }
        $this->MerchantSelectedCarrierName = $merchantSelectedCarrierName;
        return $this;
    }
    /**
     * Get Items value
     * @return \App\Delivery\Dhl\StructType\ItemsType|null
     */
    public function getItems()
    {
        return $this->Items;
    }
    /**
     * Set Items value
     * @param \App\Delivery\Dhl\StructType\ItemsType $items
     * @return \App\Delivery\Dhl\StructType\LandedCostType
     */
    public function setItems(\App\Delivery\Dhl\StructType\ItemsType $items = null)
    {
        $this->Items = $items;
        return $this;
    }
    /**
     * Get ShipmentMonetaryAmount value
     * @return \App\Delivery\Dhl\StructType\ShipmentMonetaryAmountType|null
     */
    public function getShipmentMonetaryAmount()
    {
        return $this->ShipmentMonetaryAmount;
    }
    /**
     * Set ShipmentMonetaryAmount value
     * @param \App\Delivery\Dhl\StructType\ShipmentMonetaryAmountType $shipmentMonetaryAmount
     * @return \App\Delivery\Dhl\StructType\LandedCostType
     */
    public function setShipmentMonetaryAmount(\App\Delivery\Dhl\StructType\ShipmentMonetaryAmountType $shipmentMonetaryAmount = null)
    {
        $this->ShipmentMonetaryAmount = $shipmentMonetaryAmount;
        return $this;
    }
    /**
     * Get GetTariffFormula value
     * @return string|null
     */
    public function getGetTariffFormula()
    {
        return $this->GetTariffFormula;
    }
    /**
     * Set GetTariffFormula value
     * @uses \App\Delivery\Dhl\EnumType\TariffFormula::valueIsValid()
     * @uses \App\Delivery\Dhl\EnumType\TariffFormula::getValidValues()
     * @throws \InvalidArgumentException
     * @param string $getTariffFormula
     * @return \App\Delivery\Dhl\StructType\LandedCostType
     */
    public function setGetTariffFormula($getTariffFormula = 'N')
    {
        // validation for constraint: enumeration
        if (!\App\Delivery\Dhl\EnumType\TariffFormula::valueIsValid($getTariffFormula)) {
            throw new \InvalidArgumentException(sprintf('Invalid value(s) %s, please use one of: %s from enumeration class \App\Delivery\Dhl\EnumType\TariffFormula', is_array($getTariffFormula) ? implode(', ', $getTariffFormula) : var_export($getTariffFormula, true), implode(', ', \App\Delivery\Dhl\EnumType\TariffFormula::getValidValues())), __LINE__);
        }
        $this->GetTariffFormula = $getTariffFormula;
        return $this;
    }
    /**
     * Get GetQuotationID value
     * @return string|null
     */
    public function getGetQuotationID()
    {
        return $this->GetQuotationID;
    }
    /**
     * Set GetQuotationID value
     * @uses \App\Delivery\Dhl\EnumType\GetQuotationID::valueIsValid()
     * @uses \App\Delivery\Dhl\EnumType\GetQuotationID::getValidValues()
     * @throws \InvalidArgumentException
     * @param string $getQuotationID
     * @return \App\Delivery\Dhl\StructType\LandedCostType
     */
    public function setGetQuotationID($getQuotationID = 'N')
    {
        // validation for constraint: enumeration
        if (!\App\Delivery\Dhl\EnumType\GetQuotationID::valueIsValid($getQuotationID)) {
            throw new \InvalidArgumentException(sprintf('Invalid value(s) %s, please use one of: %s from enumeration class \App\Delivery\Dhl\EnumType\GetQuotationID', is_array($getQuotationID) ? implode(', ', $getQuotationID) : var_export($getQuotationID, true), implode(', ', \App\Delivery\Dhl\EnumType\GetQuotationID::getValidValues())), __LINE__);
        }
        $this->GetQuotationID = $getQuotationID;
        return $this;
    }
    /**
     * Get GetDetailedLineItemLevelStatus value
     * @return string|null
     */
    public function getGetDetailedLineItemLevelStatus()
    {
        return $this->GetDetailedLineItemLevelStatus;
    }
    /**
     * Set GetDetailedLineItemLevelStatus value
     * @uses \App\Delivery\Dhl\EnumType\GetDetailedLineItemLevelStatus::valueIsValid()
     * @uses \App\Delivery\Dhl\EnumType\GetDetailedLineItemLevelStatus::getValidValues()
     * @throws \InvalidArgumentException
     * @param string $getDetailedLineItemLevelStatus
     * @return \App\Delivery\Dhl\StructType\LandedCostType
     */
    public function setGetDetailedLineItemLevelStatus($getDetailedLineItemLevelStatus = 'N')
    {
        // validation for constraint: enumeration
        if (!\App\Delivery\Dhl\EnumType\GetDetailedLineItemLevelStatus::valueIsValid($getDetailedLineItemLevelStatus)) {
            throw new \InvalidArgumentException(sprintf('Invalid value(s) %s, please use one of: %s from enumeration class \App\Delivery\Dhl\EnumType\GetDetailedLineItemLevelStatus', is_array($getDetailedLineItemLevelStatus) ? implode(', ', $getDetailedLineItemLevelStatus) : var_export($getDetailedLineItemLevelStatus, true), implode(', ', \App\Delivery\Dhl\EnumType\GetDetailedLineItemLevelStatus::getValidValues())), __LINE__);
        }
        $this->GetDetailedLineItemLevelStatus = $getDetailedLineItemLevelStatus;
        return $this;
    }
}
